aboutsummaryrefslogtreecommitdiff
path: root/lib/leap_cli/config/object.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/leap_cli/config/object.rb')
-rw-r--r--lib/leap_cli/config/object.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/leap_cli/config/object.rb b/lib/leap_cli/config/object.rb
index 5a5c7b1..e4fe619 100644
--- a/lib/leap_cli/config/object.rb
+++ b/lib/leap_cli/config/object.rb
@@ -184,10 +184,10 @@ module LeapCli
end
#
# returns a list of nodes that match similar production level (production, local, testing, etc)
#
def nodes_like_me
- nodes[:production => @node.production, :local => @node.local]
+ nodes[:production => @node.production, :local => @node.local, :development => @node.development]
end
class FileMissing < Exception
@@ -184,10 +184,10 @@ module LeapCli
end
#
- # returns a list of nodes that match similar production level (production, local, testing, etc)
+ # returns a list of nodes that match similar production level (production, local, development, etc)
#
def nodes_like_me